@@ -1,6 +1,14 @@
 #!/usr/bin/env perl
 
+use 5.018;
+
+use strict;
+use warnings;
+
 use Venus::Json;
 
-# use available json lib for encoding
+#
+# Use available JSON lib for encoding
+#
+
 Venus::Json->new({name => ['Ready', 'Robot'], version => 0.12, stable => !!1})->say_string('encode');
