@@ -14,6 +14,24 @@ with 'Venus::Role::Valuable';
 
 use Scalar::Util ();
 
+state $reader = {
+  js => 'read_json_file',
+  json => 'read_json_file',
+  perl => 'read_perl_file',
+  pl => 'read_perl_file',
+  yaml => 'read_yaml_file',
+  yml => 'read_yaml_file',
+};
+
+state $writer = {
+  js => 'write_json_file',
+  json => 'write_json_file',
+  perl => 'write_perl_file',
+  pl => 'write_perl_file',
+  yaml => 'write_yaml_file',
+  yml => 'write_yaml_file',
+};
+
 # BUILDERS
 
 sub build_args {
@@ -29,27 +47,21 @@ sub build_args {
 
 # METHODS
 
-sub from_file {
+sub read_file {
   my ($self, $file) = @_;
 
   if (!$file) {
     return $self->class->new;
   }
-  elsif ($file =~ /\.json$/) {
-    return $self->from_json_file($file);
-  }
-  elsif (grep $file =~ /\.${_}$/, qw(yaml yml)) {
-    return $self->from_yaml_file($file);
-  }
-  elsif (grep $file =~ /\.${_}$/, qw(perl pl)) {
-    return $self->from_perl_file($file);
+  elsif (my $method = $reader->{(split/\./, $file)[-1]}) {
+    return $self->$method($file);
   }
   else {
     return $self->class->new;
   }
 }
 
-sub from_json {
+sub read_json {
   my ($self, $data) = @_;
 
   require Venus::Json;
@@ -57,15 +69,15 @@ sub from_json {
   return $self->class->new(Venus::Json->new->decode($data));
 }
 
-sub from_json_file {
+sub read_json_file {
   my ($self, $file) = @_;
 
   require Venus::Path;
 
-  return $self->from_json(Venus::Path->new($file)->read);
+  return $self->read_json(Venus::Path->new($file)->read);
 }
 
-sub from_perl {
+sub read_perl {
   my ($self, $data) = @_;
 
   require Venus::Dump;
@@ -73,15 +85,15 @@ sub from_perl {
   return $self->class->new(Venus::Dump->new->decode($data));
 }
 
-sub from_perl_file {
+sub read_perl_file {
   my ($self, $file) = @_;
 
   require Venus::Path;
 
-  return $self->from_perl(Venus::Path->new($file)->read);
+  return $self->read_perl(Venus::Path->new($file)->read);
 }
 
-sub from_yaml {
+sub read_yaml {
   my ($self, $data) = @_;
 
   require Venus::Yaml;
@@ -89,12 +101,12 @@ sub from_yaml {
   return $self->class->new(Venus::Yaml->new->decode($data));
 }
 
-sub from_yaml_file {
+sub read_yaml_file {
   my ($self, $file) = @_;
 
   require Venus::Path;
 
-  return $self->from_yaml(Venus::Path->new($file)->read);
+  return $self->read_yaml(Venus::Path->new($file)->read);
 }
 
 sub metadata {
@@ -447,6 +459,74 @@ sub tokens {
   };
 }
 
+sub write_file {
+  my ($self, $file) = @_;
+
+  if (!$file) {
+    return $self->class->new;
+  }
+  elsif (my $method = $writer->{(split/\./, $file)[-1]}) {
+    return $self->do($method, $file);
+  }
+  else {
+    return $self->class->new;
+  }
+}
+
+sub write_json {
+  my ($self) = @_;
+
+  require Venus::Json;
+
+  return Venus::Json->new($self->value)->encode;
+}
+
+sub write_json_file {
+  my ($self, $file) = @_;
+
+  require Venus::Path;
+
+  Venus::Path->new($file)->write($self->write_json);
+
+  return $self;
+}
+
+sub write_perl {
+  my ($self) = @_;
+
+  require Venus::Dump;
+
+  return Venus::Dump->new($self->value)->encode;
+}
+
+sub write_perl_file {
+  my ($self, $file) = @_;
+
+  require Venus::Path;
+
+  Venus::Path->new($file)->write($self->write_perl);
+
+  return $self;
+}
+
+sub write_yaml {
+  my ($self) = @_;
+
+  require Venus::Yaml;
+
+  return Venus::Yaml->new($self->value)->encode;
+}
+
+sub write_yaml_file {
+  my ($self, $file) = @_;
+
+  require Venus::Path;
+
+  Venus::Path->new($file)->write($self->write_yaml);
+
+  return $self;
+}
+
 1;
 
 
@@ -471,7 +551,7 @@ Config Class for Perl 5
 
   my $config = Venus::Config->new;
 
-  # $config = $config->from_file('app.pl');
+  # $config = $config->read_file('app.pl');
 
   # my $name = $config->resolve('name');
 
@@ -511,247 +591,6 @@ This package provides the following methods:
 
 =cut
 
-=head2 from_file
-
-  from_file(Str $path) (Config)
-
-The from_file method load a Perl, YAML, or JSON configuration file, based on
-the file extension, and returns a new L<Venus::Config> object.
-
-I<Since C<1.95>>
-
-=over 4
-
-=item from_file example 1
-
-  package main;
-
-  use Venus::Config;
-
-  my $config = Venus::Config->from_file('t/conf/test.perl');
-
-  # bless(..., 'Venus::Config')
-
-=back
-
-=over 4
-
-=item from_file example 2
-
-  package main;
-
-  use Venus::Config;
-
-  my $config = Venus::Config->from_file('t/conf/test.json');
-
-  # bless(..., 'Venus::Config')
-
-=back
-
-=over 4
-
-=item from_file example 3
-
-  package main;
-
-  use Venus::Config;
-
-  my $config = Venus::Config->from_file('t/conf/test.yaml');
-
-  # bless(..., 'Venus::Config')
-
-=back
-
-=cut
-
-=head2 from_json
-
-  from_json(Str $data) (Config)
-
-The from_json method returns a new L<Venus::Config> object based on the JSON
-string provided.
-
-I<Since C<1.95>>
-
-=over 4
-
-=item from_json example 1
-
-  # given: synopsis
-
-  package main;
-
-  $config = $config->from_json(q(
-  {
-    "$metadata": {
-      "tmplog": "/tmp/log"
-    },
-    "$services": {
-      "log": { "package": "Venus/Path", "argument": { "$metadata": "tmplog" } }
-    }
-  }
-  ));
-
-  # bless(..., 'Venus::Config')
-
-  # my $log = $config->resolve('log');
-
-=back
-
-=cut
-
-=head2 from_json_file
-
-  from_json_file(Str $file) (Config)
-
-The from_json_file method uses L<Venus::Path> to return a new L<Venus::Config>
-object based on the file provided.
-
-I<Since C<1.95>>
-
-=over 4
-
-=item from_json_file example 1
-
-  # given: synopsis
-
-  package main;
-
-  $config = $config->from_json_file('t/conf/test.json');
-
-  # bless(..., 'Venus::Config')
-
-  # my $log = $config->resolve('log');
-
-=back
-
-=cut
-
-=head2 from_perl
-
-  from_perl(Str $data) (Config)
-
-The from_perl method returns a new L<Venus::Config> object based on the Perl
-string provided.
-
-I<Since C<1.95>>
-
-=over 4
-
-=item from_perl example 1
-
-  # given: synopsis
-
-  package main;
-
-  $config = $config->from_perl(q(
-  {
-    '$metadata' => {
-      tmplog => "/tmp/log"
-    },
-    '$services' => {
-      log => { package => "Venus/Path", argument => { '$metadata' => "tmplog" } }
-    }
-  }
-  ));
-
-  # bless(..., 'Venus::Config')
-
-  # my $log = $config->resolve('log');
-
-=back
-
-=cut
-
-=head2 from_perl_file
-
-  from_perl_file(Str $file) (Config)
-
-The from_perl_file method uses L<Venus::Path> to return a new L<Venus::Config>
-object based on the file provided.
-
-I<Since C<1.95>>
-
-=over 4
-
-=item from_perl_file example 1
-
-  # given: synopsis
-
-  package main;
-
-  $config = $config->from_perl_file('t/conf/test.perl');
-
-  # bless(..., 'Venus::Config')
-
-  # my $log = $config->resolve('log');
-
-=back
-
-=cut
-
-=head2 from_yaml
-
-  from_yaml(Str $data) (Config)
-
-The from_yaml method returns a new L<Venus::Config> object based on the YAML
-string provided.
-
-I<Since C<1.95>>
-
-=over 4
-
-=item from_yaml example 1
-
-  # given: synopsis
-
-  package main;
-
-  $config = $config->from_yaml(q(
-  '$metadata':
-    tmplog: /tmp/log
-  '$services':
-    log:
-      package: "Venus/Path"
-      argument:
-        '$metadata': tmplog
-  ));
-
-  # bless(..., 'Venus::Config')
-
-  # my $log = $config->resolve('log');
-
-=back
-
-=cut
-
-=head2 from_yaml_file
-
-  from_yaml_file(Str $file) (Config)
-
-The from_yaml_file method uses L<Venus::Path> to return a new L<Venus::Config>
-object based on the YAML string provided.
-
-I<Since C<1.95>>
-
-=over 4
-
-=item from_yaml_file example 1
-
-  # given: synopsis
-
-  package main;
-
-  $config = $config->from_yaml_file('t/conf/test.yaml');
-
-  # bless(..., 'Venus::Config')
-
-  # my $log = $config->resolve('log');
-
-=back
-
-=cut
-
 =head2 metadata
 
   metadata(Str $name) (Any)
@@ -784,7 +623,7 @@ I<Since C<1.95>>
 
   package main;
 
-  $config = $config->from_perl(q(
+  $config = $config->read_perl(q(
   {
     '$metadata' => {
       tmplog => "/tmp/log"
@@ -811,7 +650,7 @@ I<Since C<1.95>>
 
   package main;
 
-  $config = $config->from_perl(q(
+  $config = $config->read_perl(q(
   {
     '$metadata' => {
       tmplog => "/tmp/log"
@@ -830,6 +669,247 @@ I<Since C<1.95>>
 
 =cut
 
+=head2 read_file
+
+  read_file(Str $path) (Config)
+
+The read_file method load a Perl, YAML, or JSON configuration file, based on
+the file extension, and returns a new L<Venus::Config> object.
+
+I<Since C<2.91>>
+
+=over 4
+
+=item read_file example 1
+
+  package main;
+
+  use Venus::Config;
+
+  my $config = Venus::Config->read_file('t/conf/read.perl');
+
+  # bless(..., 'Venus::Config')
+
+=back
+
+=over 4
+
+=item read_file example 2
+
+  package main;
+
+  use Venus::Config;
+
+  my $config = Venus::Config->read_file('t/conf/read.json');
+
+  # bless(..., 'Venus::Config')
+
+=back
+
+=over 4
+
+=item read_file example 3
+
+  package main;
+
+  use Venus::Config;
+
+  my $config = Venus::Config->read_file('t/conf/read.yaml');
+
+  # bless(..., 'Venus::Config')
+
+=back
+
+=cut
+
+=head2 read_json
+
+  read_json(Str $data) (Config)
+
+The read_json method returns a new L<Venus::Config> object based on the JSON
+string provided.
+
+I<Since C<2.91>>
+
+=over 4
+
+=item read_json example 1
+
+  # given: synopsis
+
+  package main;
+
+  $config = $config->read_json(q(
+  {
+    "$metadata": {
+      "tmplog": "/tmp/log"
+    },
+    "$services": {
+      "log": { "package": "Venus/Path", "argument": { "$metadata": "tmplog" } }
+    }
+  }
+  ));
+
+  # bless(..., 'Venus::Config')
+
+  # my $log = $config->resolve('log');
+
+=back
+
+=cut
+
+=head2 read_json_file
+
+  read_json_file(Str $file) (Config)
+
+The read_json_file method uses L<Venus::Path> to return a new L<Venus::Config>
+object based on the file provided.
+
+I<Since C<2.91>>
+
+=over 4
+
+=item read_json_file example 1
+
+  # given: synopsis
+
+  package main;
+
+  $config = $config->read_json_file('t/conf/read.json');
+
+  # bless(..., 'Venus::Config')
+
+  # my $log = $config->resolve('log');
+
+=back
+
+=cut
+
+=head2 read_perl
+
+  read_perl(Str $data) (Config)
+
+The read_perl method returns a new L<Venus::Config> object based on the Perl
+string provided.
+
+I<Since C<2.91>>
+
+=over 4
+
+=item read_perl example 1
+
+  # given: synopsis
+
+  package main;
+
+  $config = $config->read_perl(q(
+  {
+    '$metadata' => {
+      tmplog => "/tmp/log"
+    },
+    '$services' => {
+      log => { package => "Venus/Path", argument => { '$metadata' => "tmplog" } }
+    }
+  }
+  ));
+
+  # bless(..., 'Venus::Config')
+
+  # my $log = $config->resolve('log');
+
+=back
+
+=cut
+
+=head2 read_perl_file
+
+  read_perl_file(Str $file) (Config)
+
+The read_perl_file method uses L<Venus::Path> to return a new L<Venus::Config>
+object based on the file provided.
+
+I<Since C<2.91>>
+
+=over 4
+
+=item read_perl_file example 1
+
+  # given: synopsis
+
+  package main;
+
+  $config = $config->read_perl_file('t/conf/read.perl');
+
+  # bless(..., 'Venus::Config')
+
+  # my $log = $config->resolve('log');
+
+=back
+
+=cut
+
+=head2 read_yaml
+
+  read_yaml(Str $data) (Config)
+
+The read_yaml method returns a new L<Venus::Config> object based on the YAML
+string provided.
+
+I<Since C<2.91>>
+
+=over 4
+
+=item read_yaml example 1
+
+  # given: synopsis
+
+  package main;
+
+  $config = $config->read_yaml(q(
+  '$metadata':
+    tmplog: /tmp/log
+  '$services':
+    log:
+      package: "Venus/Path"
+      argument:
+        '$metadata': tmplog
+  ));
+
+  # bless(..., 'Venus::Config')
+
+  # my $log = $config->resolve('log');
+
+=back
+
+=cut
+
+=head2 read_yaml_file
+
+  read_yaml_file(Str $file) (Config)
+
+The read_yaml_file method uses L<Venus::Path> to return a new L<Venus::Config>
+object based on the YAML string provided.
+
+I<Since C<2.91>>
+
+=over 4
+
+=item read_yaml_file example 1
+
+  # given: synopsis
+
+  package main;
+
+  $config = $config->read_yaml_file('t/conf/read.yaml');
+
+  # bless(..., 'Venus::Config')
+
+  # my $log = $config->resolve('log');
+
+=back
+
+=cut
+
 =head2 reify
 
   reify(Str $name) (Any)
@@ -1168,7 +1248,7 @@ I<Since C<1.95>>
 
   package main;
 
-  $config = $config->from_perl(q(
+  $config = $config->read_perl(q(
   {
     '$metadata' => {
       tmplog => "/tmp/log"
@@ -1198,7 +1278,7 @@ I<Since C<1.95>>
 
   package main;
 
-  $config = $config->from_perl(q(
+  $config = $config->read_perl(q(
   {
     '$metadata' => {
       tmplog => "/tmp/log"
@@ -1220,6 +1300,251 @@ I<Since C<1.95>>
 
 =cut
 
+=head2 write_file
+
+  write_file(Str $path) (Config)
+
+The write_file method saves a Perl, YAML, or JSON configuration file, based on
+the file extension, and returns a new L<Venus::Config> object.
+
+I<Since C<2.91>>
+
+=over 4
+
+=item write_file example 1
+
+  # given: synopsis
+
+  my $value = $config->value({
+    '$services' => {
+      log => { package => "Venus/Path", argument => { value => "." } }
+    }
+  });
+
+  $config = $config->write_file('t/conf/write.perl');
+
+  # bless(..., 'Venus::Config')
+
+=back
+
+=over 4
+
+=item write_file example 2
+
+  # given: synopsis
+
+  my $value = $config->value({
+    '$metadata' => {
+      tmplog => "/tmp/log"
+    },
+    '$services' => {
+      log => { package => "Venus/Path", argument => { '$metadata' => "tmplog" } }
+    }
+  });
+
+  $config = $config->write_file('t/conf/write.json');
+
+  # bless(..., 'Venus::Config')
+
+=back
+
+=over 4
+
+=item write_file example 3
+
+  # given: synopsis
+
+  my $value = $config->value({
+    '$metadata' => {
+      tmplog => "/tmp/log"
+    },
+    '$services' => {
+      log => { package => "Venus/Path", argument => { '$metadata' => "tmplog" } }
+    }
+  });
+
+  $config = $config->write_file('t/conf/write.yaml');
+
+  # bless(..., 'Venus::Config')
+
+=back
+
+=cut
+
+=head2 write_json
+
+  write_json() (Str)
+
+The write_json method returns a JSON encoded string based on the L</value> held
+by the underlying L<Venus::Config> object.
+
+I<Since C<2.91>>
+
+=over 4
+
+=item write_json example 1
+
+  # given: synopsis
+
+  my $value = $config->value({
+    '$services' => {
+      log => { package => "Venus::Path" },
+    },
+  });
+
+  my $json = $config->write_json;
+
+  # '{ "$services":{ "log":{ "package":"Venus::Path" } } }'
+
+=back
+
+=cut
+
+=head2 write_json_file
+
+  write_json_file(Str $path) (Config)
+
+The write_json_file method saves a JSON configuration file and returns a new
+L<Venus::Config> object.
+
+I<Since C<2.91>>
+
+=over 4
+
+=item write_json_file example 1
+
+  # given: synopsis
+
+  my $value = $config->value({
+    '$services' => {
+      log => { package => "Venus/Path", argument => { value => "." } }
+    }
+  });
+
+  $config = $config->write_json_file('t/conf/write.json');
+
+  # bless(..., 'Venus::Config')
+
+=back
+
+=cut
+
+=head2 write_perl
+
+  write_perl() (Str)
+
+The write_perl method returns a FILE encoded string based on the L</value> held
+by the underlying L<Venus::Config> object.
+
+I<Since C<2.91>>
+
+=over 4
+
+=item write_perl example 1
+
+  # given: synopsis
+
+  my $value = $config->value({
+    '$services' => {
+      log => { package => "Venus::Path" },
+    },
+  });
+
+  my $perl = $config->write_perl;
+
+  # '{ "\$services" => { log => { package => "Venus::Path" } } }'
+
+=back
+
+=cut
+
+=head2 write_perl_file
+
+  write_perl_file(Str $path) (Config)
+
+The write_perl_file method saves a Perl configuration file and returns a new
+L<Venus::Config> object.
+
+I<Since C<2.91>>
+
+=over 4
+
+=item write_perl_file example 1
+
+  # given: synopsis
+
+  my $value = $config->value({
+    '$services' => {
+      log => { package => "Venus/Path", argument => { value => "." } }
+    }
+  });
+
+  $config = $config->write_perl_file('t/conf/write.perl');
+
+  # bless(..., 'Venus::Config')
+
+=back
+
+=cut
+
+=head2 write_yaml
+
+  write_yaml() (Str)
+
+The write_yaml method returns a FILE encoded string based on the L</value> held
+by the underlying L<Venus::Config> object.
+
+I<Since C<2.91>>
+
+=over 4
+
+=item write_yaml example 1
+
+  # given: synopsis
+
+  my $value = $config->value({
+    '$services' => {
+      log => { package => "Venus::Path" },
+    },
+  });
+
+  my $yaml = $config->write_yaml;
+
+  # '---\n$services:\n\s\slog:\n\s\s\s\spackage:\sVenus::Path'
+
+=back
+
+=cut
+
+=head2 write_yaml_file
+
+  write_yaml_file(Str $path) (Config)
+
+The write_yaml_file method saves a YAML configuration file and returns a new
+L<Venus::Config> object.
+
+I<Since C<2.91>>
+
+=over 4
+
+=item write_yaml_file example 1
+
+  # given: synopsis
+
+  my $value = $config->value({
+    '$services' => {
+      log => { package => "Venus/Path", argument => { value => "." } }
+    }
+  });
+
+  $config = $config->write_yaml_file('t/conf/write.yaml');
+
+  # bless(..., 'Venus::Config')
+
+=back
+
+=cut
+
 =head1 FEATURES
 
 This package provides the following features:
