@@ -99,7 +99,7 @@ Here are examples usages using the example YAML configuration.
   # Install a distribution
   vns cpan \$DIST
 
-  # Upgrade to the latest version of Venus
+  # Install dependencies in the CWD
   vns deps
 
   # Check that a package can be compiled
@@ -503,13 +503,13 @@ run Venus::Run;
 
 =head1 NAME
 
-Venus::Run - Task Runner Class
+Venus::Run - Runner Class
 
 =cut
 
 =head1 ABSTRACT
 
-Task Runner Class for Perl 5
+Runner Class for Perl 5
 
 =cut
 
@@ -617,7 +617,7 @@ recursively resolved and expanded and will be used as environment variables.
 
 =back
 
-Here are examples usages using the example YAML configuration file and the
+Here are example usages using the example YAML configuration file and the
 L<vns> CLI.
 
   # Mint a new configuration file
@@ -628,32 +628,32 @@ L<vns> CLI.
   # Install a distribution
   vns cpan $DIST
 
-  ... same as $(which cpanm) --llocal -qn $DIST
+  i.e. $(which cpanm) --llocal -qn $DIST
 
-  # Upgrade to the latest version of Venus
+  # Install dependencies in the CWD
   vns deps
 
-  ... same as $(which cpanm) --llocal -qn --installdeps .
+  i.e. $(which cpanm) --llocal -qn --installdeps .
 
   # Check that a package can be compiled
   vns okay $FILE
 
-  ... same as $(which perl) -Ilib -Ilocal/lib/perl5 -c $FILE
+  i.e. $(which perl) -Ilib -Ilocal/lib/perl5 -c $FILE
 
   # Use the Perl debugger as a REPL
   vns repl
 
-  ... same as $(which perl) -Ilib -Ilocal/lib/perl5 -dE0
+  i.e. $(which perl) -Ilib -Ilocal/lib/perl5 -dE0
 
   # Evaluate arbitrary Perl expressions
   vns exec ...
 
-  ... same as $(which perl) -Ilib -Ilocal/lib/perl5 -MVenus=log -E $@
+  i.e. $(which perl) -Ilib -Ilocal/lib/perl5 -MVenus=log -E $@
 
   # Test the Perl project in the CWD
   vns test t
 
-  ... same as $(which prove) -Ilib -Ilocal/lib/perl5
+  i.e. $(which prove) -Ilib -Ilocal/lib/perl5 t
 
 This package and CLI allows you to define task definitions for any application,
 which you can run using the name of the task. You can reuse existing task
